#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_IS_NOT_EQUAL_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_IS_NOT_EQUAL_HPP_INCLUDED

#include <boost/simd/operator/include/functions/is_not_equal.hpp>

#endif
